@@ -67,6 +67,7 @@ def process(
     made_changes: bool = False
     stripped_line: str = ""
     end_of_file: bool = False
+    verbose_output: List[str] = []
 
     if config.float_to_top:
         new_input = ""
@@ -83,7 +84,11 @@ def process(
                 if line == "# isort: off\n":
                     isort_off = True
                 if current:
+                    if add_imports:
+                        current += line_separator + line_separator.join(add_imports)
+                        add_imports = []
                     parsed = parse.file_contents(current, config=config)
+                    verbose_output += parsed.verbose_output
                     extra_space = ""
                     while current and current[-1] == "\n":
                         extra_space += "\n"
@@ -153,6 +158,7 @@ def process(
                     in_top_comment = False
                     first_comment_index_end = index - 1
 
+            was_in_quote = bool(in_quote)
             if (not stripped_line.startswith("#") or in_quote) and '"' in line or "'" in line:
                 char_index = 0
                 if first_comment_index_start == -1 and (
@@ -178,8 +184,8 @@ def process(
                         break
                     char_index += 1
 
-            not_imports = bool(in_quote) or in_top_comment or isort_off
-            if not (in_quote or in_top_comment):
+            not_imports = bool(in_quote) or was_in_quote or in_top_comment or isort_off
+            if not (in_quote or was_in_quote or in_top_comment):
                 if isort_off:
                     if stripped_line == "# isort: on":
                         isort_off = False
@@ -322,8 +328,11 @@ def process(
                             line[len(indent) :] for line in import_section.splitlines(keepends=True)
                         )
 
+                    parsed_content = parse.file_contents(import_section, config=config)
+                    verbose_output += parsed_content.verbose_output
+
                     sorted_import_section = output.sorted_imports(
-                        parse.file_contents(import_section, config=config),
+                        parsed_content,
                         _indented_config(config, indent),
                         extension,
                         import_type="cimport" if cimports else "import",
@@ -381,6 +390,10 @@ def process(
                         output_stream.write(new_line)
                         stripped_line = new_line.strip().split("#")[0]
 
+    if made_changes and config.only_modified:
+        for output_str in verbose_output:
+            print(output_str)
+
     return made_changes
 
 
